@@ -1,7 +1,7 @@
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2014 Keio University
+#     Copyright (C) 2001-2016 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: G::IO::Handler.pm,v 1.1 2002/07/30 17:44:27 gaou Exp $
@@ -1775,8 +1775,12 @@ sub _interpret_format {
 	return 'fasta';
     }elsif (lc($filename) =~ /\.(fastq|fq)/i){
 	return 'fastq';
-    }elsif (lc($filename) =~ /\.(embl)/i){
-	return 'embl';
+    }elsif (lc($filename) =~ /\.(gff3)/i){
+	return 'gff3';
+    }elsif (lc($filename) =~ /\.(gff2)/i){
+	return 'gff2';
+    }elsif (lc($filename) =~ /\.(gff)/i){
+	return 'gff';
     }elsif ($filename =~ /^NC_\d+$/i ||
 	    $filename =~ /^NP_\d+$/i ||
 	    $filename =~ /^(?:[A-Z]|[A-Z][A-Z]).\d+$/i ||
