@@ -1,7 +1,7 @@
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2014 Keio University
+#     Copyright (C) 2001-2016 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 # G-language GAE is free software; you can redistribute it and/or
@@ -191,7 +191,7 @@ sub readFile{
     }
 
     unless($format){
-	if ($file =~ /\:\/\//){
+	if ($file =~ /\:\/\// && $file !~ / /){
 	    $format = 'url';
 	}elsif (lc($file) =~ /\.(fasta|fast|seq|fst|fa|fsa|nt|aa|ffn|fna)/i){
 	    $format = 'fasta';
