@@ -1,7 +1,7 @@
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2014 Keio University
+#     Copyright (C) 2001-2016 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Consensus.pm,v 1.2 2002/07/30 17:40:56 gaou Exp $
@@ -118,7 +118,7 @@ sub base_counter{
     my $nuc;
     my $cnuc;
 
-    $PatLen--;
+#    $PatLen--;
     $downstream++;
 
     foreach my $cds ($gb->cds()){
@@ -136,8 +136,8 @@ sub base_counter{
 	    for($i=$upstream;$i>-$downstream;$i--){
 		if($start-1-$i>0){
 		    $hash[$upstream-$i]{kazu}++;
-		    $nuc=$gb->getseq($start-1-$i,$start-1-$i+$PatLen);
-		    next if(length($nuc != $PatLen));
+		    $nuc=$gb->getseq($start-1-$i,$start-1-$i+$PatLen - 1);
+		    next if(length($nuc) != $PatLen);
 		    $hash[$upstream-$i]{$nuc}++;
 		    $hash[0]{pat}{$nuc}++;
 		}
@@ -157,7 +157,7 @@ sub base_counter{
 	    for($i=$upstream;$i>-$downstream;$i--){
 		if($start-1+$i<length($gb->{SEQ})){
 		    $hash[$upstream-$i]{kazu}++;
-		    $nuc=$gb->getseq($start-1+$i-$PatLen,$start-1+$i);
+		    $nuc=$gb->getseq($start-1+$i-$PatLen-1,$start-1+$i);
 		    $cnuc=complement($nuc);
 		    $hash[$upstream-$i]{$cnuc}++;
 		    $hash[0]{pat}{$cnuc}++;
@@ -286,7 +286,7 @@ sub logmod{
 
 =head2 base_entropy
 
-  Name: base_entropy   -   calculates and graphs the sequence conservation using Shanon uncertainty (entropy)
+  Name: base_entropy   -   calculates and graphs the sequence conservation using Shannon uncertainty (entropy)
 
   Description:
     This function calculates and graphs the sequence conservation in regions 
@@ -304,7 +304,7 @@ sub logmod{
                                           "base_entropy.csv" for -output=>"f")
     -position   either "start" (around start codon) or "end" (around stop codon)
                 to create the PWM (default: "start");
-    -PatLen     length of oligomer to count (default: 3)
+    -PatLength  length of oligomer to count (default: 3)
     -upstream   length upstream of specified position to create PWM (default: 30)
     -downstream length downstream of specified position to create PWM (default: 30)
 
