@@ -1,7 +1,7 @@
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2014 Keio University
+#     Copyright (C) 2001-2016 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: PatSearch.pm,v 1.3 2002/07/30 17:40:56 gaou Exp $
@@ -282,10 +282,8 @@ sub markov {
    20101010 initial posting
 
   References:
-   Campbell A et al. (1999) Proc Natl Acad Sci U S A. 96(16):9184-9.
-   Karlin S. (2001) Trends Microbiol. 9(7):335-43.
-
-  Requirements: none.
+   Campbell A et al. (1999) Proc Natl Acad Sci U S A. 96(16):9184-9. PMID: 10430917
+   Karlin S. (2001) Trends Microbiol. 9(7):335-43. PMID: 11435108
 
 =cut
 
@@ -303,7 +301,6 @@ sub signature {
     my $header     = opt_val("header");
 
     my ($total, %mono, %obs, %exp, %val);
-
     $seq = $gb->{SEQ} unless($seq);
     $seq .= ' '.complement($seq) if($bothstrand);
 
@@ -316,33 +313,38 @@ sub signature {
     $mono{c} = $seq =~ tr/c/c/;
     $mono{g} = $seq =~ tr/g/g/;
     $mono{t} = $seq =~ tr/t/t/;
-    foreach (keys %mono){ $mono{$_} =  $mono{$_} / $total; }
+    foreach (keys %mono){ 
+	$mono{$_} =  $mono{$_} / $total; 
+    }
 
     for(my $i = 0; $i < length($seq) - $wordlength + 1; $i ++){
 	$obs{substr($seq, $i, $wordlength)} ++;
     }
 
     $total = 0;
-    foreach (keys %obs){ delete $obs{$_} if($_ =~ /[^acgt]/); $total += $obs{$_}; }
+    foreach (keys %obs){ 
+	delete $obs{$_} if($_ =~ /[^acgt]/); $total += $obs{$_};
+    }
     foreach (keys %obs){
 	$exp{$_} = 1;
-	for(my $i = 0; $i < $wordlength; $i ++){ $exp{$_} *= $mono{substr($_,$i,1)}; }
-	if($oe){ $val{$_} = sprintf("%.3f", ($obs{$_}/$total)/$exp{$_}); } 
-	else { $val{$_} = sprintf("%.3f", $obs{$_}/$total); }
-    }
-
-    if(0){
-	print "mono=",%mono, "\n";
-	print "mono.total = [$total]\n";
-	print "obs=", %obs, "\n";
-	print "oligo.total = [$total]\n";
+	for(my $i = 0; $i < $wordlength; $i ++){ 
+	    $exp{$_} *= $mono{substr($_,$i,1)};
+	}
+	if($oe){
+	    $val{$_} = sprintf("%.3f", ($obs{$_}/$total)/$exp{$_}); 
+	}
+	else { 
+	    $val{$_} = sprintf("%.3f", $obs{$_}/$total);
+	}
     }
 
     my @allkey = qw(a c g t);
     for(1..($wordlength-1)){
 	my @tmp = ();
 	for my $base (qw(a c g t)){
-	    foreach my $key (@allkey){ push(@tmp, $key.$base); }
+	    foreach my $key (@allkey){ 
+		push(@tmp, $key.$base); 
+	    }
 	}
 	@allkey = @tmp;
     }
@@ -368,20 +370,18 @@ sub signature {
     ##### 
     
     if($output =~ /stdout/){
-	foreach(@allkey){ msg_send("$_\t"); } msg_send("memo\n");
-	foreach(@allkey){ msg_send("$val{$_}\t"); } msg_send("$memo\n");
+	msg_send("$_\t") foreach(@allkey); msg_send("memo\n");
+	msg_send("$val{$_}\t") foreach(@allkey); msg_send("$memo\n");
     }
-
     if($output eq 'f'){
 	mkdir ("data", 0777);
 	open(OUT, ">>data/$filename");
-	if($header){ print OUT join(',', @allkey), ",memo\n"; }
+	print OUT join(',', @allkey), ",memo\n" if($header);
 	my @tmp;
-	foreach (@allkey){ push(@tmp, $val{$_} || 0); }
+	push(@tmp, $val{$_} || 0) foreach (@allkey);
 	print OUT join(',', @tmp), ",$memo\n";
 	close(OUT);
     }
-
     $gb->{signature} = \%val; # input in the G instance
     return \%val;
 }
@@ -424,10 +424,12 @@ sub signature {
    Suzuki H et al. (2008) Nucleic Acids Res. 36(22):e147.
    Suzuki H et al. (2010) J Bacteriol. 192(22):6045-55.
 
-  Requirements: sub signature()
+  Requirements: signature()
 
 =cut
 
+
+
 sub signature_dist {
     &opt_default(output=>'stdout', wordlength=>2, window=>5000, step=>5000, method=>'mahalanobis');
     my @args       = opt_get(@_);
@@ -791,6 +793,7 @@ sub find_iteron {
     
   History:
     20071107-01 initial posting
+
 =cut
 
 
