@@ -1,7 +1,7 @@
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2014 Keio University
+#     Copyright (C) 2001-2016 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Primitive.pm,v 1.1 2002/07/30 17:44:27 gaou Exp $
@@ -64,7 +64,7 @@ our @EXPORT = qw(
 #          Constants
 #::::::::::::::::::::::::::::::
 
-my %CodonTable = (
+our %CodonTable = (
 	       'gac', 'D', 'caa', 'Q', 'gca', 'A', 'ctg', 'L',
 	       'gat', 'D', 'cag', 'Q', 'gcc', 'A', 'ctt', 'L',
 	       'gaa', 'E', 'agc', 'S', 'gcg', 'A', 'ata', 'I',
@@ -86,14 +86,14 @@ my %CodonTable = (
 
 # http://www.ncbi.nlm.nih.gov/Taxonomy/Utils/wprintgc.cgi
 # 2. The Vertebrate Mitochondrial Code
-my %CodonTable2 = %CodonTable;
+our %CodonTable2 = %CodonTable;
 $CodonTable2{'aga'} = '/';
 $CodonTable2{'agg'} = '/';
 $CodonTable2{'ata'} = 'M';
 $CodonTable2{'tga'} = 'W';
 
 # 3. The Yeast Mitochondrial Code
-my %CodonTable3 = %CodonTable;
+our %CodonTable3 = %CodonTable;
 $CodonTable3{'ata'} = 'M';
 $CodonTable3{'ctt'} = 'T';
 $CodonTable3{'ctc'} = 'T';
@@ -104,48 +104,48 @@ $CodonTable3{'cga'} = '/'; # absent
 $CodonTable3{'cgc'} = '/'; # absent
 
 # 4. The Mold, Protozoan, and Coelenterate Mitochondrial Code and the Mycoplasma/Spiroplasma Code
-my %CodonTable4 = %CodonTable;
+our %CodonTable4 = %CodonTable;
 $CodonTable4{'tga'} = 'W';
 
 # 5. The Invertebrate Mitochondrial Code
-my %CodonTable5 = %CodonTable;
+our %CodonTable5 = %CodonTable;
 $CodonTable5{'aga'} = 'S';
 $CodonTable5{'agg'} = 'S';
 $CodonTable5{'ata'} = 'M';
 $CodonTable5{'tga'} = 'W';
 
 # 6. The Ciliate, Dasycladacean and Hexamita Nuclear Code
-my %CodonTable6 = %CodonTable;
+our %CodonTable6 = %CodonTable;
 $CodonTable6{'taa'} = 'Q';
 $CodonTable6{'tag'} = 'Q';
 
 # 9. The Echinoderm and Flatworm Mitochondrial Code#
-my %CodonTable9 = %CodonTable;
+our %CodonTable9 = %CodonTable;
 $CodonTable9{'aaa'} = 'N';
 $CodonTable9{'aga'} = 'S';
 $CodonTable9{'agg'} = 'S';
 $CodonTable9{'tga'} = 'W';
 
 # 10. The Euplotid Nuclear Code
-my %CodonTable10 = %CodonTable;
+our %CodonTable10 = %CodonTable;
 $CodonTable10{'tga'} = 'C';
 
 # 11. The Bacterial, Archaeal and Plant Plastid Code
-my %CodonTable11 = %CodonTable;
+our %CodonTable11 = %CodonTable;
 
 # 12. The Alternative Yeast Nuclear Code
-my %CodonTable12 = %CodonTable;
+our %CodonTable12 = %CodonTable;
 $CodonTable12{'ctg'} = 'S';
 
 # 13. The Ascidian Mitochondrial Code
-my %CodonTable13 = %CodonTable;
+our %CodonTable13 = %CodonTable;
 $CodonTable13{'aga'} = 'G';
 $CodonTable13{'agg'} = 'G';
 $CodonTable13{'ata'} = 'M';
 $CodonTable13{'tga'} = 'W';
 
 # 14. The Alternative Flatworm Mitochondrial Code
-my %CodonTable14 = %CodonTable;
+our %CodonTable14 = %CodonTable;
 $CodonTable14{'aaa'} = 'N';
 $CodonTable14{'aga'} = 'S';
 $CodonTable14{'agg'} = 'S';
@@ -153,11 +153,11 @@ $CodonTable14{'taa'} = 'Y';
 $CodonTable14{'tga'} = 'W';
 
 # 16. Chlorophycean Mitochondrial Code
-my %CodonTable16 = %CodonTable;
+our %CodonTable16 = %CodonTable;
 $CodonTable16{'tag'} = 'L';
 
 # 21. Trematode Mitochondrial Code
-my %CodonTable21 = %CodonTable;
+our %CodonTable21 = %CodonTable;
 $CodonTable21{'tga'} = 'W';
 $CodonTable21{'ata'} = 'M';
 $CodonTable21{'aga'} = 'S';
@@ -165,23 +165,23 @@ $CodonTable21{'agg'} = 'S';
 $CodonTable21{'aaa'} = 'N';
 
 # 22. Scenedesmus obliquus Mitochondrial Code
-my %CodonTable22 = %CodonTable;
+our %CodonTable22 = %CodonTable;
 $CodonTable22{'tca'} = '/';
 $CodonTable22{'tag'} = 'L';
 
 # 23. Thraustochytrium Mitochondrial Code
  # it contains an additional stop codon (TTA) and also has a different set of start codons.
-my %CodonTable23 = %CodonTable;
+our %CodonTable23 = %CodonTable;
 $CodonTable23{'tta'} = '/';
 
 # 24. Pterobranchia Mitochondrial Code
-my %CodonTable24 = %CodonTable;
+our %CodonTable24 = %CodonTable;
 $CodonTable24{'aga'} = 'S';
 $CodonTable24{'agg'} = 'K';
 $CodonTable24{'tga'} = 'W';
 
 # 25. Candidate Division SR1 and Gracilibacteria Code
-my %CodonTable25 = %CodonTable;
+our %CodonTable25 = %CodonTable;
 $CodonTable25{'tga'} = 'G';
 
 my @CodonTables = ('', \%CodonTable2, \%CodonTable3, \%CodonTable4, \%CodonTable5, \%CodonTable6, '', '', \%CodonTable9, \%CodonTable10, \%CodonTable11, \%CodonTable12,
@@ -251,6 +251,8 @@ my @CodonTables = ('', \%CodonTable2, \%CodonTable3, \%CodonTable4, \%CodonTable
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+    20160104-01 fixed a serious bug in the previous revision, where the default codon table
+                was set to be number 25 instead of 1
     20141114-01 added alternative codon tables
     20091203-01 added cutom codon table option
     20010727-01 initial posting
@@ -259,10 +261,11 @@ my @CodonTables = ('', \%CodonTable2, \%CodonTable3, \%CodonTable4, \%CodonTable
 
 
 sub translate {
+    opt_default("table"=>1);
     my @args  = opt_get(@_);
     my $seq   = lc(shift @args);
     my $table = opt_val("table"); 
-    my %option = @_;
+    my %option = @args;
 
     my %codons = %CodonTable;
     %codons = %{$CodonTables[$table - 1]} if(length($CodonTables[$table - 1]));
@@ -275,15 +278,18 @@ sub translate {
 
     while(3 <= length($seq)){
 	my $codon = substr($seq, 0, 3);
+
 	substr($seq, 0, 3) = '';
 	if ($codon =~ /[^atgc]/){
 	    $amino .= 'X';
 	}else{
 	    $amino .= $codons{$codon};
 	}
+#	p %codons;
+#	say $amino;
     }
 
-    msg_error("Translation: illegal length.\n") if(length($seq));
+    msg_error("Translation: illegal length.\n") if(length($seq) && $option{"silent"} != 1);
 
     return $amino;
 }
