@@ -1,7 +1,7 @@
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2014 Keio University
+#     Copyright (C) 2001-2016 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: EPCR.pm,v 1.1.1.1 2002/04/02 20:25:44 gaou Exp $
@@ -77,37 +77,25 @@ sub cognitor {
     my $hit = opt_val("hit");
 
     my $ua = LWP::UserAgent->new();
-    my $req = POST 'http://www.ncbi.nlm.nih.gov/COG/old/xognitor.cgi',
-    [seq=>$gb->{SEQ}, hit=>$hit];
+    my $req = POST 'http://www.ncbi.nlm.nih.gov/Structure/cdd/wrpsb.cgi',
+    [seqinput=>$gb->{SEQ}, db=>oasis_cog, evalue=>"0.010000", filter=>'', compbasedadj=>'T', frclive=>'T', lift=>'', maxhits=>'50', mode=>full];
     my $content = $ua->request($req)->as_string;
 
-    if ($content =~ /NO related COG/){
-	#return '';
-    }elsif($content =~ /<table/){
-	$content =~ s/\///g;
-	my (undef, $line, $undef) = split(/table/, $content, 3);
-	substr($line, 0, 1) = '<';
-	$line =~ s/<.*?>/ /g;
-	my (undef, @lines) = split(/\n/, $line);
-	
-	my $i = 0;
-	foreach (@lines){
-	    s/^\s*//g;
-	    s/\s*$//g;
-	    if (/(\d+)\s+proteins/){
-		$lines[$i] = $1;
-	    }elsif(/BeTs to\s+(\d+)\s+clades/){
-		$lines[$i] = $1;
-	    }elsif(/pet-score:\s+(\d+)/){
-		$lines[$i] = $1;
+    if($content =~ /name="dhandle" type="hidden" value="(.*?)"><input/){
+	sleep(5);
+	$content = $ua->get('http://www.ncbi.nlm.nih.gov/Structure/cdd/wrpsb.cgi?dhandle=' . $1)->as_string;
+	if($content =~ /var jsonData = (.*);/){
+	    use JSON;
+	    my $obj = from_json($1, {utf8=>1});
+	    for my $key (@{$obj->{alns}}){
+		my $id = $key->{pssmid};
+		say join ("\t", $obj->{doms}->{$id}->{acc}, $key->{alnev}, $obj->{doms}->{$id}->{defl});
 	    }
-	    
-	    $i ++;
+	}else{
+	    die("Cognitor failed.");
 	}
-	
-	return ($lines[2], $lines[1], $lines[3], $lines[0], $lines[4], $lines[5]);
-	#       COGID      FUNCTION   PRODUCT    HITS       BeTs       pet-score
     }
+
 }
 
 sub dignitor{
