@@ -1,7 +1,7 @@
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2014 Keio University
+#     Copyright (C) 2001-2016 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 # G-language GAE is free software; you can redistribute it and/or
@@ -301,9 +301,9 @@ sub hclust {
 
 
 
-=head2 kmeans()
+=head2 kmeans
 
-  Name: kmeans()   -   clustering with K-means method
+  Name: kmeans   -   clustering with K-means method
 
   Description:
     
